window.Gleam.initSearch([{"doc":"carpenter","title":"carpenter","content":"# carpenter 🔨\n\n[![Package Version](https://img.shields.io/hexpm/v/carpenter)](https://hex.pm/packages/carpenter)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/carpenter/)\n\nBindings for Erlang&#39;s [ETS tables](https://www.erlang.org/doc/man/ets.html). Forked and updated from [gts](https://github.com/Lunarmagpie/gts). \n\nIf you aren&#39;t familiar with ETS tables, [this](https://elixirschool.com/en/lessons/storage/ets) is a good introduction.\n\n\n## Quick start\n\n```gleam\nimport gleam/io\nimport carpenter/table\n\npub fn main() {\n  // Set up and configure an ETS table\n  let example: table.Set(String, String) =\n    table.build(&quot;table_name&quot;)\n    |&gt; table.set\n    |&gt; table.privacy(table.Private)\n    |&gt; table.write_concurrency(table.AutoWriteConcurrency)\n    |&gt; table.read_concurrency(True)\n    |&gt; table.decentralized_counters(True)\n    |&gt; table.compression(False)\n\n  // Insert a value\n  example\n  |&gt; table.insert(&quot;hello&quot;, &quot;world&quot;)\n\n  // Retrieve a key-value tuple\n  example\n  |&gt; table.lookup(&quot;hello&quot;)\n  |&gt; set.debug\n\n  // Delete an object\n  example\n  |&gt; table.delete(&quot;hello&quot;)\n\n  // Delete a table\n  example\n  |&gt; table.drop\n}\n```\n\n## Installation\n\nThis package is available on hex:\n\n```sh\ngleam add carpenter\n```\n\nIts documentation can be found at &lt;https://hexdocs.pm/carpenter&gt;.\n","url":"index.html"},{"doc":"carpenter/table","title":"Privacy","content":"pub type Privacy {\n  Private\n  Protected\n  Public\n}\n\nPrivate\n\n\nProtected\n\n\nPublic\n\n\nSynonyms:\ncarpenter/table.Privacy\ncarpenter/table Privacy","url":"carpenter/table.html#Privacy"},{"doc":"carpenter/table","title":"Set","content":"pub type Set(k, v) {\n  Set(table: Table(k, v))\n}\n\nSet(table: Table(k, v))\n\n\nSynonyms:\ncarpenter/table.Set\ncarpenter/table Set","url":"carpenter/table.html#Set"},{"doc":"carpenter/table","title":"Table","content":"pub type Table(k, v) {\n  Table(name: atom.Atom)\n}\n\nTable(name: atom.Atom)\n\n\nSynonyms:\ncarpenter/table.Table\ncarpenter/table Table","url":"carpenter/table.html#Table"},{"doc":"carpenter/table","title":"TableBuilder","content":"pub type TableBuilder(k, v) {\n  TableBuilder(\n    name: String,\n    privacy: Option(Privacy),\n    write_concurrency: Option(WriteConcurrency),\n    read_concurrency: Option(Bool),\n    decentralized_counters: Option(Bool),\n    compressed: Bool,\n  )\n}\n\nTableBuilder(\n  name: String,\n  privacy: Option(Privacy),\n  write_concurrency: Option(WriteConcurrency),\n  read_concurrency: Option(Bool),\n  decentralized_counters: Option(Bool),\n  compressed: Bool,\n)\n\n\nSynonyms:\ncarpenter/table.TableBuilder\ncarpenter/table TableBuilder","url":"carpenter/table.html#TableBuilder"},{"doc":"carpenter/table","title":"WriteConcurrency","content":"pub type WriteConcurrency {\n  WriteConcurrency\n  NoWriteConcurrency\n  AutoWriteConcurrency\n}\n\nWriteConcurrency\n\n\nNoWriteConcurrency\n\n\nAutoWriteConcurrency\n\n\nSynonyms:\ncarpenter/table.WriteConcurrency\ncarpenter/table WriteConcurrency","url":"carpenter/table.html#WriteConcurrency"},{"doc":"carpenter/table","title":"build","content":"pub fn build(name: String) -&gt; TableBuilder(a, b)\n Begin building a new table with the given name. Ensure your table names are unique, \n otherwise you will encounter a `badarg` failure at runtime when attempting to build it.\nSynonyms:\ncarpenter/table.build\ncarpenter/table build","url":"carpenter/table.html#build"},{"doc":"carpenter/table","title":"compression","content":"pub fn compression(\n  builder: TableBuilder(a, b),\n  compressed: Bool,\n) -&gt; TableBuilder(a, b)\n Whether or not the table is compressed.\nSynonyms:\ncarpenter/table.compression\ncarpenter/table compression","url":"carpenter/table.html#compression"},{"doc":"carpenter/table","title":"decentralized_counters","content":"pub fn decentralized_counters(\n  builder: TableBuilder(a, b),\n  counters: Bool,\n) -&gt; TableBuilder(a, b)\n Whether or not the table uses decentralized_counters.\n Acceptable values are `True` or `False`.\n \n You should probably choose `True` unless you are going to be polling\n the table for its size and memory usage frequently.\nSynonyms:\ncarpenter/table.decentralized_counters\ncarpenter/table decentralized_counters","url":"carpenter/table.html#decentralized_counters"},{"doc":"carpenter/table","title":"delete","content":"pub fn delete(set: Set(a, b), key: a) -&gt; Set(a, b)\n Delete all objects with key `key` from the table.\nSynonyms:\ncarpenter/table.delete\ncarpenter/table delete","url":"carpenter/table.html#delete"},{"doc":"carpenter/table","title":"delete_all","content":"pub fn delete_all(set: Set(a, b)) -&gt; Set(a, b)\n Delete all objects belonging to a table\nSynonyms:\ncarpenter/table.delete_all\ncarpenter/table delete_all","url":"carpenter/table.html#delete_all"},{"doc":"carpenter/table","title":"drop","content":"pub fn drop(set: Set(a, b)) -&gt; Nil\n Deletes the entire table.\nSynonyms:\ncarpenter/table.drop\ncarpenter/table drop","url":"carpenter/table.html#drop"},{"doc":"carpenter/table","title":"give_away","content":"pub fn give_away(set: Set(a, b), pid: Pid, gift_data: c) -&gt; Nil\n Give the table to another process.\nSynonyms:\ncarpenter/table.give_away\ncarpenter/table give_away","url":"carpenter/table.html#give_away"},{"doc":"carpenter/table","title":"insert","content":"pub fn insert(set: Set(a, b), key: a, value: b) -&gt; Set(a, b)\n Insert a value into the ets table.\nSynonyms:\ncarpenter/table.insert\ncarpenter/table insert","url":"carpenter/table.html#insert"},{"doc":"carpenter/table","title":"lookup","content":"pub fn lookup(set: Set(a, b), key: a) -&gt; Option(List(#(a, b)))\n Retrieve a value from the ets table. Return an option if the value could\n not be found.\nSynonyms:\ncarpenter/table.lookup\ncarpenter/table lookup","url":"carpenter/table.html#lookup"},{"doc":"carpenter/table","title":"ordered_set","content":"pub fn ordered_set(builder: TableBuilder(a, b)) -&gt; Set(a, b)\n Specify table as an `ordered_set`\nSynonyms:\ncarpenter/table.ordered_set\ncarpenter/table ordered_set","url":"carpenter/table.html#ordered_set"},{"doc":"carpenter/table","title":"privacy","content":"pub fn privacy(\n  builder: TableBuilder(a, b),\n  privacy: Privacy,\n) -&gt; TableBuilder(a, b)\n Set the privacy of the table.\n Acceptable values are `Private`, `Protected`, and `Public`.\nSynonyms:\ncarpenter/table.privacy\ncarpenter/table privacy","url":"carpenter/table.html#privacy"},{"doc":"carpenter/table","title":"read_concurrency","content":"pub fn read_concurrency(\n  builder: TableBuilder(a, b),\n  con: Bool,\n) -&gt; TableBuilder(a, b)\n Whether or not the table uses read_concurrency. Acceptable values are `True` or `False.\nSynonyms:\ncarpenter/table.read_concurrency\ncarpenter/table read_concurrency","url":"carpenter/table.html#read_concurrency"},{"doc":"carpenter/table","title":"set","content":"pub fn set(builder: TableBuilder(a, b)) -&gt; Set(a, b)\n Specify table as a `set`\nSynonyms:\ncarpenter/table.set\ncarpenter/table set","url":"carpenter/table.html#set"},{"doc":"carpenter/table","title":"write_concurrency","content":"pub fn write_concurrency(\n  builder: TableBuilder(a, b),\n  con: WriteConcurrency,\n) -&gt; TableBuilder(a, b)\n Set the write_concurrency of the table.\n Acceptable values are `WriteConcurrency`, `NoWriteConcurrency`, or `AutoWriteConcurrency`.\nSynonyms:\ncarpenter/table.write_concurrency\ncarpenter/table write_concurrency","url":"carpenter/table.html#write_concurrency"},{"doc":"carpenter/table","title":"carpenter/table","content":"","url":"carpenter/table.html"}]);